==> haskell-cprng-aes-0.6.1-96-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-HrMMpvMTwly9yOGD2vVgxm
key: cprng-aes-0.6.1-HrMMpvMTwly9yOGD2vVgxm
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
abi: aebac853ebd6ac25e4696b6494e63ddf
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-HrMMpvMTwly9yOGD2vVgxm
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 cipher-aes-0.2.11-FEFaIecbSdD4SWRSjVxIKs
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cprng-aes-0.6.1-105-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cprng-aes.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cprng-aes
version: 0.6.1
id: cprng-aes-0.6.1-92ZRei9ZKkaFHyJQCnQDt3
key: cprng-aes-0.6.1-92ZRei9ZKkaFHyJQCnQDt3
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
stability: experimental
homepage: http://github.com/vincenthz/hs-cprng-aes
synopsis: Crypto Pseudo Random Number Generator using AES in counter mode.
description:
    Simple crypto pseudo-random-number-generator with really good randomness property.
    .
    Using ent, a randomness property maker on one 1Mb sample:
    Entropy = 7.999837 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 237.02
    Arithmetic mean value of data bytes is 127.3422 (127.5 = random)
    Monte Carlo value for Pi is 3.143589568 (error 0.06 percent)
    .
    Compared to urandom with the same sampling:
    Entropy = 7.999831 bits per byte.
    Optimum compression would reduce the size of this 1048576 byte file by 0 percent.
    Chi square distribution for 1048576 samples is 246.63
    Arithmetic mean value of data bytes is 127.6347 (127.5 = random).
    Monte Carlo value for Pi is 3.132465868 (error 0.29 percent).
category: Cryptography
abi: fb9aefb4101b906d6ca4bac7856a005b
exposed: True
exposed-modules:
    Crypto.Random.AESCtr
hidden-modules: Crypto.Random.AESCtr.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/cprng-aes-0.6.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/cprng-aes-0.6.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-cprng-aes
hs-libraries: HScprng-aes-0.6.1-92ZRei9ZKkaFHyJQCnQDt3
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 cipher-aes-0.2.11-9AQVkLnXjCkKEt3BMixXJL
    crypto-random-0.0.9-E4aYqliD5SsKzXXmOmCF7H
haddock-interfaces: /usr/share/doc/haskell-cprng-aes/html/cprng-aes.haddock
haddock-html: /usr/share/doc/haskell-cprng-aes/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
